shell_var_name

Function shell_var_name 

pub fn shell_var_name(shell: &str) -> String
Keyed by the program rather than the subcommand, because that is what the value names. usage powershell runs pwsh, so its variable is USAGE_SHELL_PWSH.