Returns the arguments that this program was started with (normally passed
via the command line).
Returns the arguments that this program was started with (normally passed
via the command line).
Returns the current working directory as a
PathBuf.
Returns the full filesystem path of the current running executable.
Returns the path of the current user’s home directory if known.
Joins a collection of
Paths appropriately for the
PATH
environment variable.
Removes an environment variable from the environment of the currently running process.
Changes the current working directory to the specified path.
Sets the environment variable key to the value value for the currently running
process.
Parses input according to platform conventions for the PATH
environment variable.
Returns the path of a temporary directory.
Fetches the environment variable key from the current process.
Fetches the environment variable
key from the current process, returning
None if the variable isn’t set or if there is another error.
Returns an iterator of (variable, value) pairs of strings, for all the
environment variables of the current process.
Returns an iterator of (variable, value) pairs of OS strings, for all the
environment variables of the current process.