pub fn shell_var_name(shell: &str) -> String
Keyed by the program rather than the subcommand, because that is what the value names. usage powershell runs pwsh, so its variable is USAGE_SHELL_PWSH.
usage powershell
pwsh
USAGE_SHELL_PWSH